bsdkrun/volumes
Host-level operations on persistent volumes.
Values
pub fn remove(
names: List(String),
force: Bool,
) -> Result(Nil, error.Error)
Remove one or more volumes, and the data they hold.
Host-level operations on persistent volumes.
pub fn remove(
names: List(String),
force: Bool,
) -> Result(Nil, error.Error)
Remove one or more volumes, and the data they hold.